@@ -34,22 +34,30 @@ class SignalBot:
     def __init__(self, signalcli_host: str,
                  signalcli_port: typing.Union[str, int],
                  remote_data_path: str = "/data",
-                 local_data_path: str = "/data") -> None:
+                 local_data_path: str = "/data",
+                 call_timeout: float = 5.0,
+                 call_delay: float = 0.3) -> None:
         """"""
         self.signalcli_host = signalcli_host
         self.signalcli_port = int(signalcli_port)
         self.remote_data_path = remote_data_path
         self.local_data_path = local_data_path
+        self.call_timeout = call_timeout
+        self.call_delay = call_delay
         self.stickerpacks = []
         self.refresh_stickerpacks()
         self.dispatcher = Dispatcher(self)
 
     async def rpc_call(self, method: str, params: dict | None = None,
-                       timeout: float = 5.0, delay: float = 0.3) -> Response:
+                       timeout: float | None = None, delay: float | None = None) -> Response:
         """"""
         request_id = str(uuid.uuid4())
         payload = {"jsonrpc":"2.0", "method":method, "params":params,
                    "id":request_id}
+        if timeout is None:
+            timeout = self.call_timeout
+        if delay is None:
+            delay = self.call_delay
         await self.dispatcher.send(payload)
         try:
             async with async_timeout.timeout(timeout):
