@@ -78,14 +78,11 @@ class Dispatcher:
                 return
             if self.connected is False:
                 await self.connect()
-            for sig in [signal.SIGTERM, signal.SIGINT]:
-                asyncio.get_running_loop().add_signal_handler(
-                    sig, lambda: asyncio.create_task(self.disconnect()))
             while True:
                 payload = await self.stream_reader.readline()
                 if payload == b"":
                     if self.planned_disconnect is True:
-                        self.log.info("Disconnecting...")
+                        self.log.warning("Manually disconnecting...")
                         return
                     self.log.error("Socket connection error! Reconnecting...")
                     await self.disconnect()
@@ -96,6 +93,7 @@ class Dispatcher:
                 task.add_done_callback(self.dispatch_tasks.discard)
             self.running = True
         except asyncio.CancelledError:
+            self.log.warning("Socket loop task cancelled, disconnecting...")
             await self.disconnect()
 
     def add_handler(self, handler: GeneralHandler) -> None:
